==> react-ui-library-0.0.30.tgz: package/src/stories/avatar-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Avatar,
  Box,
  Triangle
} from '../components'

const imageURL = 'http://www.casinomeister.com/forums/avatars/jufo.gif?dateline=1345999507'

export default function avatarStory (module) {
  storiesOf('Avatar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Avatar

The Avatar component allows easy avatar composition. Implements \`<Box />\`.

* Falls back to initials on error
* Adds a title attribute with the name

\`\`\`
const imageURL = '${imageURL}'

<Avatar src={imageURL}>Segment Sloth</Avatar>
<Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
\`\`\`

`}
          </Content>
          <Avatar marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\`| string | undefined | the name of the avatar/person displayed
\`imageSize\`| string / small, default | 40px | the width and height of the image
\`nameShown\`| boolean | false | wether to show a name under the Avatar
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with circle only', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Avatar marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar marginLeft={2} marginRight={2} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with name shown', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Avatar nameShown marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown marginLeft={2} marginRight={2} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with Triangle', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Box flex alignItems='center'>
            <Avatar marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
            <Triangle aim='down' inlineFlex />
          </Box>
        </Pane>
      </App>
    ))
}

==> react-ui-library-0.2.1.tgz: package/src/stories/avatar-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Avatar,
  Box,
  Triangle
} from '../components'

const imageURL = 'http://www.casinomeister.com/forums/avatars/jufo.gif?dateline=1345999507'

export default function avatarStory (module) {
  storiesOf('Avatar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Avatar

The Avatar component allows easy avatar composition. Implements \`<Box />\`.

* Falls back to initials on error
* Adds a title attribute with the name

\`\`\`
const imageURL = '${imageURL}'

<Avatar src={imageURL}>Segment Sloth</Avatar>
<Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
\`\`\`

`}
          </Content>
          <Avatar marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\`| string | undefined | the name of the avatar/person displayed
\`imageSize\`| string / small, default | 40px | the width and height of the image
\`nameShown\`| boolean | false | wether to show a name under the Avatar
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with circle only', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Avatar marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar marginLeft={2} marginRight={2} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with name shown', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Avatar nameShown marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown marginLeft={2} marginRight={2} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with Triangle', () => (
      <App>
        <Pane white padding={5} clearfix>
          <Box display='flex' alignItems='center'>
            <Avatar marginLeft={2} marginRight={2} src={imageURL}>Segment Sloth</Avatar>
            <Triangle aim='down' inlineFlex />
          </Box>
        </Pane>
      </App>
    ))
}
